@@ -29,8 +29,17 @@ def printcolor(txt, sameline=False, color=get_colour("white")):
 
 def drange(start, stop, step=1.0):
     "generate between 2 numbers w/ optional step"
+    if step==0:
+        step = 0.01
     r = start
     while r < stop:
         yield r
         r += step
 
+def box_text(text, width, offset=0):
+    box = " "*offset + "-"*(width+2) + "\n"
+    box += " "*offset + "|"+ text.center(width) + "|" + "\n"
+    box += " "*offset + "-"*(width+2)
+    return box
+
+
